/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:POINTER (../cinnamon-session/cinnamon-session/csm-marshal.list:1) */
extern
void csm_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN,BOOLEAN,STRING (../cinnamon-session/cinnamon-session/csm-marshal.list:2) */
extern
void csm_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN_STRING (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN,POINTER (../cinnamon-session/cinnamon-session/csm-marshal.list:3) */
extern
void csm_marshal_VOID__BOOLEAN_BOOLEAN_POINTER (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);


G_END_DECLS
