/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CSM_EXPORTED_APP_H__
#define __CSM_EXPORTED_APP_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.SessionManager.App */

#define CSM_TYPE_EXPORTED_APP (csm_exported_app_get_type ())
#define CSM_EXPORTED_APP(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_APP, CsmExportedApp))
#define CSM_IS_EXPORTED_APP(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_APP))
#define CSM_EXPORTED_APP_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CSM_TYPE_EXPORTED_APP, CsmExportedAppIface))

struct _CsmExportedApp;
typedef struct _CsmExportedApp CsmExportedApp;
typedef struct _CsmExportedAppIface CsmExportedAppIface;

struct _CsmExportedAppIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_get_app_id) (
    CsmExportedApp *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_phase) (
    CsmExportedApp *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_startup_id) (
    CsmExportedApp *object,
    GDBusMethodInvocation *invocation);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedApp, g_object_unref)
#endif

GType csm_exported_app_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *csm_exported_app_interface_info (void);
guint csm_exported_app_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void csm_exported_app_complete_get_app_id (
    CsmExportedApp *object,
    GDBusMethodInvocation *invocation,
    const gchar *app_id);

void csm_exported_app_complete_get_startup_id (
    CsmExportedApp *object,
    GDBusMethodInvocation *invocation,
    const gchar *startup_id);

void csm_exported_app_complete_get_phase (
    CsmExportedApp *object,
    GDBusMethodInvocation *invocation,
    guint phase);



/* D-Bus method calls: */
void csm_exported_app_call_get_app_id (
    CsmExportedApp *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_app_call_get_app_id_finish (
    CsmExportedApp *proxy,
    gchar ** out_app_id,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_app_call_get_app_id_sync (
    CsmExportedApp *proxy,
    gchar ** out_app_id,
    GCancellable *cancellable,
    GError **error);

void csm_exported_app_call_get_startup_id (
    CsmExportedApp *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_app_call_get_startup_id_finish (
    CsmExportedApp *proxy,
    gchar ** out_startup_id,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_app_call_get_startup_id_sync (
    CsmExportedApp *proxy,
    gchar ** out_startup_id,
    GCancellable *cancellable,
    GError **error);

void csm_exported_app_call_get_phase (
    CsmExportedApp *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_app_call_get_phase_finish (
    CsmExportedApp *proxy,
    guint* out_phase,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_app_call_get_phase_sync (
    CsmExportedApp *proxy,
    guint* out_phase,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CSM_TYPE_EXPORTED_APP_PROXY (csm_exported_app_proxy_get_type ())
#define CSM_EXPORTED_APP_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_APP_PROXY, CsmExportedAppProxy))
#define CSM_EXPORTED_APP_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CSM_TYPE_EXPORTED_APP_PROXY, CsmExportedAppProxyClass))
#define CSM_EXPORTED_APP_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CSM_TYPE_EXPORTED_APP_PROXY, CsmExportedAppProxyClass))
#define CSM_IS_EXPORTED_APP_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_APP_PROXY))
#define CSM_IS_EXPORTED_APP_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CSM_TYPE_EXPORTED_APP_PROXY))

typedef struct _CsmExportedAppProxy CsmExportedAppProxy;
typedef struct _CsmExportedAppProxyClass CsmExportedAppProxyClass;
typedef struct _CsmExportedAppProxyPrivate CsmExportedAppProxyPrivate;

struct _CsmExportedAppProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsmExportedAppProxyPrivate *priv;
};

struct _CsmExportedAppProxyClass
{
  GDBusProxyClass parent_class;
};

GType csm_exported_app_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedAppProxy, g_object_unref)
#endif

void csm_exported_app_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsmExportedApp *csm_exported_app_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsmExportedApp *csm_exported_app_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void csm_exported_app_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsmExportedApp *csm_exported_app_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsmExportedApp *csm_exported_app_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CSM_TYPE_EXPORTED_APP_SKELETON (csm_exported_app_skeleton_get_type ())
#define CSM_EXPORTED_APP_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_APP_SKELETON, CsmExportedAppSkeleton))
#define CSM_EXPORTED_APP_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CSM_TYPE_EXPORTED_APP_SKELETON, CsmExportedAppSkeletonClass))
#define CSM_EXPORTED_APP_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CSM_TYPE_EXPORTED_APP_SKELETON, CsmExportedAppSkeletonClass))
#define CSM_IS_EXPORTED_APP_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_APP_SKELETON))
#define CSM_IS_EXPORTED_APP_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CSM_TYPE_EXPORTED_APP_SKELETON))

typedef struct _CsmExportedAppSkeleton CsmExportedAppSkeleton;
typedef struct _CsmExportedAppSkeletonClass CsmExportedAppSkeletonClass;
typedef struct _CsmExportedAppSkeletonPrivate CsmExportedAppSkeletonPrivate;

struct _CsmExportedAppSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsmExportedAppSkeletonPrivate *priv;
};

struct _CsmExportedAppSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType csm_exported_app_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedAppSkeleton, g_object_unref)
#endif

CsmExportedApp *csm_exported_app_skeleton_new (void);


G_END_DECLS

#endif /* __CSM_EXPORTED_APP_H__ */
