/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CSM_EXPORTED_INHIBITOR_H__
#define __CSM_EXPORTED_INHIBITOR_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.SessionManager.Inhibitor */

#define CSM_TYPE_EXPORTED_INHIBITOR (csm_exported_inhibitor_get_type ())
#define CSM_EXPORTED_INHIBITOR(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_INHIBITOR, CsmExportedInhibitor))
#define CSM_IS_EXPORTED_INHIBITOR(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_INHIBITOR))
#define CSM_EXPORTED_INHIBITOR_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CSM_TYPE_EXPORTED_INHIBITOR, CsmExportedInhibitorIface))

struct _CsmExportedInhibitor;
typedef struct _CsmExportedInhibitor CsmExportedInhibitor;
typedef struct _CsmExportedInhibitorIface CsmExportedInhibitorIface;

struct _CsmExportedInhibitorIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_get_app_id) (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_client_id) (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_flags) (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_reason) (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_toplevel_xid) (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedInhibitor, g_object_unref)
#endif

GType csm_exported_inhibitor_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *csm_exported_inhibitor_interface_info (void);
guint csm_exported_inhibitor_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void csm_exported_inhibitor_complete_get_app_id (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation,
    const gchar *app_id);

void csm_exported_inhibitor_complete_get_client_id (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation,
    const gchar *client_id);

void csm_exported_inhibitor_complete_get_reason (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation,
    const gchar *reason);

void csm_exported_inhibitor_complete_get_flags (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation,
    guint flags);

void csm_exported_inhibitor_complete_get_toplevel_xid (
    CsmExportedInhibitor *object,
    GDBusMethodInvocation *invocation,
    guint xid);



/* D-Bus method calls: */
void csm_exported_inhibitor_call_get_app_id (
    CsmExportedInhibitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_inhibitor_call_get_app_id_finish (
    CsmExportedInhibitor *proxy,
    gchar ** out_app_id,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_inhibitor_call_get_app_id_sync (
    CsmExportedInhibitor *proxy,
    gchar ** out_app_id,
    GCancellable *cancellable,
    GError **error);

void csm_exported_inhibitor_call_get_client_id (
    CsmExportedInhibitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_inhibitor_call_get_client_id_finish (
    CsmExportedInhibitor *proxy,
    gchar ** out_client_id,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_inhibitor_call_get_client_id_sync (
    CsmExportedInhibitor *proxy,
    gchar ** out_client_id,
    GCancellable *cancellable,
    GError **error);

void csm_exported_inhibitor_call_get_reason (
    CsmExportedInhibitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_inhibitor_call_get_reason_finish (
    CsmExportedInhibitor *proxy,
    gchar ** out_reason,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_inhibitor_call_get_reason_sync (
    CsmExportedInhibitor *proxy,
    gchar ** out_reason,
    GCancellable *cancellable,
    GError **error);

void csm_exported_inhibitor_call_get_flags (
    CsmExportedInhibitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_inhibitor_call_get_flags_finish (
    CsmExportedInhibitor *proxy,
    guint* out_flags,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_inhibitor_call_get_flags_sync (
    CsmExportedInhibitor *proxy,
    guint* out_flags,
    GCancellable *cancellable,
    GError **error);

void csm_exported_inhibitor_call_get_toplevel_xid (
    CsmExportedInhibitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_inhibitor_call_get_toplevel_xid_finish (
    CsmExportedInhibitor *proxy,
    guint* out_xid,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_inhibitor_call_get_toplevel_xid_sync (
    CsmExportedInhibitor *proxy,
    guint* out_xid,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CSM_TYPE_EXPORTED_INHIBITOR_PROXY (csm_exported_inhibitor_proxy_get_type ())
#define CSM_EXPORTED_INHIBITOR_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_INHIBITOR_PROXY, CsmExportedInhibitorProxy))
#define CSM_EXPORTED_INHIBITOR_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CSM_TYPE_EXPORTED_INHIBITOR_PROXY, CsmExportedInhibitorProxyClass))
#define CSM_EXPORTED_INHIBITOR_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CSM_TYPE_EXPORTED_INHIBITOR_PROXY, CsmExportedInhibitorProxyClass))
#define CSM_IS_EXPORTED_INHIBITOR_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_INHIBITOR_PROXY))
#define CSM_IS_EXPORTED_INHIBITOR_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CSM_TYPE_EXPORTED_INHIBITOR_PROXY))

typedef struct _CsmExportedInhibitorProxy CsmExportedInhibitorProxy;
typedef struct _CsmExportedInhibitorProxyClass CsmExportedInhibitorProxyClass;
typedef struct _CsmExportedInhibitorProxyPrivate CsmExportedInhibitorProxyPrivate;

struct _CsmExportedInhibitorProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsmExportedInhibitorProxyPrivate *priv;
};

struct _CsmExportedInhibitorProxyClass
{
  GDBusProxyClass parent_class;
};

GType csm_exported_inhibitor_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedInhibitorProxy, g_object_unref)
#endif

void csm_exported_inhibitor_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsmExportedInhibitor *csm_exported_inhibitor_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsmExportedInhibitor *csm_exported_inhibitor_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void csm_exported_inhibitor_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsmExportedInhibitor *csm_exported_inhibitor_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsmExportedInhibitor *csm_exported_inhibitor_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CSM_TYPE_EXPORTED_INHIBITOR_SKELETON (csm_exported_inhibitor_skeleton_get_type ())
#define CSM_EXPORTED_INHIBITOR_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_INHIBITOR_SKELETON, CsmExportedInhibitorSkeleton))
#define CSM_EXPORTED_INHIBITOR_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CSM_TYPE_EXPORTED_INHIBITOR_SKELETON, CsmExportedInhibitorSkeletonClass))
#define CSM_EXPORTED_INHIBITOR_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CSM_TYPE_EXPORTED_INHIBITOR_SKELETON, CsmExportedInhibitorSkeletonClass))
#define CSM_IS_EXPORTED_INHIBITOR_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_INHIBITOR_SKELETON))
#define CSM_IS_EXPORTED_INHIBITOR_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CSM_TYPE_EXPORTED_INHIBITOR_SKELETON))

typedef struct _CsmExportedInhibitorSkeleton CsmExportedInhibitorSkeleton;
typedef struct _CsmExportedInhibitorSkeletonClass CsmExportedInhibitorSkeletonClass;
typedef struct _CsmExportedInhibitorSkeletonPrivate CsmExportedInhibitorSkeletonPrivate;

struct _CsmExportedInhibitorSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsmExportedInhibitorSkeletonPrivate *priv;
};

struct _CsmExportedInhibitorSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType csm_exported_inhibitor_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedInhibitorSkeleton, g_object_unref)
#endif

CsmExportedInhibitor *csm_exported_inhibitor_skeleton_new (void);


G_END_DECLS

#endif /* __CSM_EXPORTED_INHIBITOR_H__ */
