/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CSM_EXPORTED_DIALOG_H__
#define __CSM_EXPORTED_DIALOG_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.cinnamon.SessionManager.EndSessionDialog */

#define CSM_TYPE_EXPORTED_DIALOG (csm_exported_dialog_get_type ())
#define CSM_EXPORTED_DIALOG(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_DIALOG, CsmExportedDialog))
#define CSM_IS_EXPORTED_DIALOG(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_DIALOG))
#define CSM_EXPORTED_DIALOG_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CSM_TYPE_EXPORTED_DIALOG, CsmExportedDialogIface))

struct _CsmExportedDialog;
typedef struct _CsmExportedDialog CsmExportedDialog;
typedef struct _CsmExportedDialogIface CsmExportedDialogIface;

struct _CsmExportedDialogIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_cancel) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_capabilities) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_hibernate) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_ignore_inhibitors) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_logout) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_restart) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_shutdown) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_suspend) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_switch_user) (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

  void (*inhibitors_changed) (
    CsmExportedDialog *object,
    GVariant *arg_capabilities);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedDialog, g_object_unref)
#endif

GType csm_exported_dialog_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *csm_exported_dialog_interface_info (void);
guint csm_exported_dialog_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void csm_exported_dialog_complete_suspend (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_hibernate (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_restart (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_shutdown (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_switch_user (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_logout (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_cancel (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_ignore_inhibitors (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation);

void csm_exported_dialog_complete_get_capabilities (
    CsmExportedDialog *object,
    GDBusMethodInvocation *invocation,
    GVariant *capabilities);



/* D-Bus signal emissions functions: */
void csm_exported_dialog_emit_inhibitors_changed (
    CsmExportedDialog *object,
    GVariant *arg_capabilities);



/* D-Bus method calls: */
void csm_exported_dialog_call_suspend (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_suspend_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_suspend_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_hibernate (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_hibernate_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_hibernate_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_restart (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_restart_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_restart_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_shutdown (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_shutdown_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_shutdown_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_switch_user (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_switch_user_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_switch_user_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_logout (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_logout_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_logout_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_cancel (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_cancel_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_cancel_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_ignore_inhibitors (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_ignore_inhibitors_finish (
    CsmExportedDialog *proxy,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_ignore_inhibitors_sync (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GError **error);

void csm_exported_dialog_call_get_capabilities (
    CsmExportedDialog *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean csm_exported_dialog_call_get_capabilities_finish (
    CsmExportedDialog *proxy,
    GVariant ** out_capabilities,
    GAsyncResult *res,
    GError **error);

gboolean csm_exported_dialog_call_get_capabilities_sync (
    CsmExportedDialog *proxy,
    GVariant ** out_capabilities,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CSM_TYPE_EXPORTED_DIALOG_PROXY (csm_exported_dialog_proxy_get_type ())
#define CSM_EXPORTED_DIALOG_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_DIALOG_PROXY, CsmExportedDialogProxy))
#define CSM_EXPORTED_DIALOG_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CSM_TYPE_EXPORTED_DIALOG_PROXY, CsmExportedDialogProxyClass))
#define CSM_EXPORTED_DIALOG_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CSM_TYPE_EXPORTED_DIALOG_PROXY, CsmExportedDialogProxyClass))
#define CSM_IS_EXPORTED_DIALOG_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_DIALOG_PROXY))
#define CSM_IS_EXPORTED_DIALOG_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CSM_TYPE_EXPORTED_DIALOG_PROXY))

typedef struct _CsmExportedDialogProxy CsmExportedDialogProxy;
typedef struct _CsmExportedDialogProxyClass CsmExportedDialogProxyClass;
typedef struct _CsmExportedDialogProxyPrivate CsmExportedDialogProxyPrivate;

struct _CsmExportedDialogProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsmExportedDialogProxyPrivate *priv;
};

struct _CsmExportedDialogProxyClass
{
  GDBusProxyClass parent_class;
};

GType csm_exported_dialog_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedDialogProxy, g_object_unref)
#endif

void csm_exported_dialog_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsmExportedDialog *csm_exported_dialog_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsmExportedDialog *csm_exported_dialog_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void csm_exported_dialog_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsmExportedDialog *csm_exported_dialog_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsmExportedDialog *csm_exported_dialog_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CSM_TYPE_EXPORTED_DIALOG_SKELETON (csm_exported_dialog_skeleton_get_type ())
#define CSM_EXPORTED_DIALOG_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CSM_TYPE_EXPORTED_DIALOG_SKELETON, CsmExportedDialogSkeleton))
#define CSM_EXPORTED_DIALOG_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CSM_TYPE_EXPORTED_DIALOG_SKELETON, CsmExportedDialogSkeletonClass))
#define CSM_EXPORTED_DIALOG_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CSM_TYPE_EXPORTED_DIALOG_SKELETON, CsmExportedDialogSkeletonClass))
#define CSM_IS_EXPORTED_DIALOG_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CSM_TYPE_EXPORTED_DIALOG_SKELETON))
#define CSM_IS_EXPORTED_DIALOG_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CSM_TYPE_EXPORTED_DIALOG_SKELETON))

typedef struct _CsmExportedDialogSkeleton CsmExportedDialogSkeleton;
typedef struct _CsmExportedDialogSkeletonClass CsmExportedDialogSkeletonClass;
typedef struct _CsmExportedDialogSkeletonPrivate CsmExportedDialogSkeletonPrivate;

struct _CsmExportedDialogSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsmExportedDialogSkeletonPrivate *priv;
};

struct _CsmExportedDialogSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType csm_exported_dialog_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsmExportedDialogSkeleton, g_object_unref)
#endif

CsmExportedDialog *csm_exported_dialog_skeleton_new (void);


G_END_DECLS

#endif /* __CSM_EXPORTED_DIALOG_H__ */
